==> landtax-1.0.0-20160518.023814-5-sources.jar: cn/gtmap/landtax/service/ZdhcService.java <==
package cn.gtmap.landtax.service;/**
 * Created by janeshen on 2014/8/21.
 */

import cn.gtmap.landtax.entity.SSjGtbd;
import cn.gtmap.landtax.model.query.GtSwTzQuery;
import cn.gtmap.landtax.model.query.SwDjSyQuery;
import com.gtis.plat.wf.model.PerformerTaskModel;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.ui.Model;

import java.util.HashMap;
import java.util.List;

/**
 * .
 * <p/>
 *  国土宗地核查服务
 * @author shenjian
 * @version V1.0, 2014/8/21
 */

public interface ZdhcService {
    public List<SSjGtbd> getGtbdById(String[] gtbdId);
    public List<SSjGtbd> getDxfGtbdByDjh(String[] djh);
    public SSjGtbd getGtbdById(String gtbdId);

//    public void saveGtbzCztdysHcdjb(GtDjTzQuery gtDjTzQuery);

//    public void saveGtbzFcsHcdjb(GtDjTzQuery gtDjTzQuery);

    Page<GtSwTzQuery> findGtppxxMap(String xzqbh, String lx, Pageable request, GtSwTzQuery sSjGtbd);

    /**
     * 删除未匹配宗地核查的工作流项目，即一个核查项目中的单个核查任务。
     */
    void delZdhcRw(String proid);

    public void saveSwDjSy(SwDjSyQuery swDjSyQuery) throws  Exception;

    List<GtSwTzQuery> getWhczdList(HashMap param);
    public List<SSjGtbd> findGtppxxList(String xzqbh, String lx, GtSwTzQuery gtSwTzQuery);

    Page<GtSwTzQuery> yxflbJson(Pageable request, GtSwTzQuery sSjGtbd);

    Object getZtByGtbdId(String gtbdId);

    void delWorkflow(String sgqdm);

    void autoCreateWorkflow(String sgqdm) throws  Exception;

    public String initTurnTaskXml(String proid,String userId,String taskid)throws Exception;

    Object getTJrws(GtSwTzQuery sSjGtbd) throws  Exception;

    HashMap getSyScmjSumByDjh(String djh);

    /**
     * //根据当前登录用户判断是否显示删除，和自动创建按钮
     * @param zdhcDelBtnRoleName
     * @param zdhcAutoCreRoleName
     * @param zdhcCreateRoleName
     * @param model
     */
    public void isShowBtnByRoleName(String zdhcDelBtnRoleName,String zdhcAutoCreRoleName,String zdhcCreateRoleName,Model model);

    public PerformerTaskModel getTurnUserList(String userId,String proid) throws  Exception;
}

==> landtax-1.0.0-20161009.022418-24-sources.jar: cn/gtmap/landtax/service/ZdhcService.java <==
package cn.gtmap.landtax.service;/**
 * Created by janeshen on 2014/8/21.
 */

import cn.gtmap.landtax.entity.SSjGtbd;
import cn.gtmap.landtax.model.query.GtSwTzQuery;
import cn.gtmap.landtax.model.query.SwDjSyQuery;
import com.gtis.plat.wf.model.PerformerTaskModel;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.ui.Model;

import java.util.HashMap;
import java.util.List;

/**
 * .
 * <p/>
 *  国土宗地核查服务
 * @author shenjian
 * @version V1.0, 2014/8/21
 */

public interface ZdhcService {
    public List<SSjGtbd> getGtbdById(String[] gtbdId);
    public List<SSjGtbd> getDxfGtbdByDjh(String[] djh);
    public SSjGtbd getGtbdById(String gtbdId);

//    public void saveGtbzCztdysHcdjb(GtDjTzQuery gtDjTzQuery);

//    public void saveGtbzFcsHcdjb(GtDjTzQuery gtDjTzQuery);

    Page<GtSwTzQuery> findGtppxxMap(String xzqbh, String lx, Pageable request, GtSwTzQuery sSjGtbd);

    /**
     * 删除未匹配宗地核查的工作流项目，即一个核查项目中的单个核查任务。
     */
    void delZdhcRw(String proid);

    public void saveSwDjSy(SwDjSyQuery swDjSyQuery) throws  Exception;

    List<GtSwTzQuery> getWhczdList(HashMap param);
    public List<SSjGtbd> findGtppxxList(String xzqbh, String lx, GtSwTzQuery gtSwTzQuery);

    Page<GtSwTzQuery> yxflbJson(Pageable request, GtSwTzQuery sSjGtbd);

    Object getZtByGtbdId(String gtbdId);

    void delWorkflow(String sgqdm,String djh);

    void autoCreateWorkflow(String sgqdm) throws  Exception;

    public String initTurnTaskXml(String proid,String userId,String taskid)throws Exception;

    Object getTJrws(GtSwTzQuery sSjGtbd) throws  Exception;

    HashMap getSyScmjSumByDjh(String djh);

    /**
     * //根据当前登录用户判断是否显示删除，和自动创建按钮
     * @param zdhcDelBtnRoleName
     * @param zdhcAutoCreRoleName
     * @param zdhcCreateRoleName
     * @param model
     */
    public void isShowBtnByRoleName(String zdhcDelBtnRoleName,String zdhcAutoCreRoleName,String zdhcCreateRoleName,Model model);

    public PerformerTaskModel getTurnUserList(String userId,String proid) throws  Exception;
}
